@@ -9,13 +9,13 @@ Portability: portable
 Create fully interactive HTML applications with type-safe serverside Haskell. Inspired by [HTMX](https://htmx.org/), [Elm](https://elm-lang.org/), and [Phoenix LiveView](https://www.phoenixframework.org/)
 -}
 module Web.Hyperbole
-  ( -- * Introduction
+  ( -- * Introduction #intro#
     -- $use
 
-    -- * Getting started
+    -- * Getting started #start#
     -- $hello
 
-    -- ** HTML Views
+    -- ** HTML Views #views#
     -- $view-functions-intro
 
     -- ** Interactive HyperViews #hyperviews#
@@ -24,59 +24,74 @@ module Web.Hyperbole
     -- ** View Functions #viewfunctions#
     -- $view-functions
 
-    -- * Managing State
+    -- * Managing State #state#
     -- $state-parameters
 
-    -- ** Side Effects
+    -- ** Side Effects #side-effects#
     -- $state-effects
 
-    -- ** Databases and Custom Effects
+    -- ** Databases and Custom Effects #databases#
     -- $state-databases
 
-    -- * Multiple HyperViews
+    -- * Multiple HyperViews #hyperview-multi#
     -- $practices-multi
 
-    -- ** Copies
+    -- ** Same HyperView, Unique ViewId #hyperview-same#
     -- $practices-same
 
-    -- ** Nesting
+    -- ** Different HyperViews
+    -- $practices-diff
+
+    -- ** Nesting HyperViews #hyperview-nested#
     -- $practices-nested
 
     -- * Functions, not Components #reusable#
     -- $reusable
 
-    -- * Pages #pages#
+    -- * Pages and Routes #pages#
     -- $practices-pages
 
-    -- * Examples
+    -- * Examples #examples#
     -- $examples
 
-    -- * Application
+    -- * Application #application#
     liveApp
   , Warp.run
-  , basicDocument
+
+    -- ** Page
   , Page
   , runPage
 
-    -- ** Type-Safe Routes
-  , routeRequest -- maybe belongs in an application section
+    -- ** Document
+  , document
+  , quickStartDocument
+  , DocumentHead
+  , quickStart
+  , mobileFriendly
+
+    -- ** Type-Safe Routes #routes#
   , Route (..)
-  , routeUrl
+  , routeRequest -- maybe belongs in an application section
+  , routeUri
   , route
 
-    -- * Hyperbole Effect
+    -- * Hyperbole Effect #hyperbole-effect#
   , Hyperbole
 
-    -- ** Response
-  , respondEarly
-  , notFound
-  , redirect
-
-    -- ** Request
+    -- ** Request #request#
   , request
   , Request (..)
 
-    -- ** Query Params #query#
+    -- ** Response #response#
+  , respondError
+  , respondErrorView
+  , notFound
+  , redirect
+
+    -- ** Query #query#
+    -- $query
+  , ToQuery (..)
+  , FromQuery (..)
   , query
   , setQuery
   , param
@@ -86,20 +101,28 @@ module Web.Hyperbole
   , queryParams
 
     -- ** Sessions #sessions#
+    -- $sessions
+  , Session (..)
   , session
   , saveSession
   , lookupSession
   , modifySession
   , modifySession_
   , deleteSession
-  , Session (..)
 
-    -- * HyperView
+    -- ** Control Client #client#
+  , pageTitle
+  , trigger
+  , pushEvent
+
+    -- * HyperView #hyperview#
   , HyperView (..)
+  , ViewId
+  , ViewAction
   , hyper
   , HasViewId (..)
 
-    -- * Interactive Elements
+    -- * Interactive Elements #interactive#
   , button
   , search
   , dropdown
@@ -109,22 +132,25 @@ module Web.Hyperbole
     -- * Events
   , onClick
   , onDblClick
+  , onMouseEnter
+  , onMouseLeave
   , onInput
+  , onLoad
+  , DelayMs
   , onKeyDown
   , onKeyUp
-  , onLoad
-  , onRequest
   , Key (..)
-  , DelayMs
 
-    -- * Type-Safe Forms
-
-    -- | Painless forms with type-checked field names, and support for validation. See [Example.Forms](https://docs.hyperbole.live/formsimple)
+    -- * Type-Safe Forms #forms#
+    -- $forms
+  , FromForm (..)
+  , FromFormF (..)
   , formData
-  , Form (..)
-  , formFields
-  , formFieldsWith
-  , FormField
+  , GenFields (..)
+  , fieldNames
+  , FieldName (..)
+  , FormFields
+  -- , FormField (..)
   , Field
   , Identity
 
@@ -133,44 +159,43 @@ module Web.Hyperbole
   , field
   , label
   , input
+  , checkbox
+  , radioGroup
+  , radio
+  , select
+  , checked
   , textarea
   , submit
-  , placeholder
+  , View.placeholder
   , InputType (..)
 
     -- ** Validation
   , Validated (..)
+  , isInvalid
   , validate
-  , fieldValid
   , invalidText
-  , anyInvalid
 
-    -- * Query Param Encoding
-  , ToQuery (..)
-  , FromQuery (..)
+    -- * Query Param Encoding #query-param#
+  , QueryData
   , ToParam (..)
   , FromParam (..)
-  , QueryData
-  , DefaultParam (..)
+  , ToEncoded
+  , FromEncoded
 
-    -- * Advanced
+    -- * Advanced #advanced#
   , target
-  , view
   , Response
-  , ViewId
-  , ViewAction
   , Root
 
-    -- * Exports
+    -- * Exports #exports#
 
-    -- ** Web.View
-
-    -- | Hyperbole is tightly integrated with [Web.View](https://hackage.haskell.org/package/web-view/docs/Web-View.html) for HTML generation
-  , module Web.View
+    -- ** View
+  , View (..)
+  , module View
 
     -- ** Embeds
 
-    -- | Embedded CSS and Javascript to include in your document function. See 'basicDocument'
+    -- | Embedded CSS and Javascript to include in your document function. See 'quickStartDocument'
   , module Web.Hyperbole.View.Embed
 
     -- ** Effectful
@@ -178,33 +203,45 @@ module Web.Hyperbole
   , module Effectful
 
     -- ** Other
+  , URI (..)
+  , uri
   , Application
-  , Generic
+  , module GHC.Generics
+  , Default (..)
+  , ToJSON
+  , FromJSON
   ) where
 
+import Data.Aeson (FromJSON, ToJSON)
+import Data.Default
 import Effectful (Eff, (:>))
+import GHC.Generics (Generic, Rep)
 import Network.Wai (Application)
 import Network.Wai.Handler.Warp as Warp (run)
+import Web.Atomic.CSS ()
+import Web.Atomic.Types ()
 import Web.Hyperbole.Application
+import Web.Hyperbole.Data.Encoded (FromEncoded, ToEncoded)
+import Web.Hyperbole.Data.Param
 import Web.Hyperbole.Data.QueryData
-import Web.Hyperbole.Data.Session
+import Web.Hyperbole.Document
+import Web.Hyperbole.Effect.Client
 import Web.Hyperbole.Effect.Hyperbole
 import Web.Hyperbole.Effect.Query
 import Web.Hyperbole.Effect.Request
-import Web.Hyperbole.Effect.Response (notFound, redirect, respondEarly, view)
-import Web.Hyperbole.Effect.Server
+import Web.Hyperbole.Effect.Response
 import Web.Hyperbole.Effect.Session
 import Web.Hyperbole.HyperView
+import Web.Hyperbole.HyperView.Forms
 import Web.Hyperbole.Page (Page, runPage)
 import Web.Hyperbole.Route
-import Web.Hyperbole.View
+import Web.Hyperbole.Types.Request
+import Web.Hyperbole.Types.Response
+import Web.Hyperbole.View hiding (placeholder)
+import Web.Hyperbole.View qualified as View hiding (Attributable, Attributes, View)
 import Web.Hyperbole.View.Embed
-import Web.Hyperbole.View.Forms
-import Web.View hiding (Query, Segment, button, cssResetEmbed, form, input, label)
 
 
--- import Web.View.Types.Url (Segment)
-
 {- $use
 
 Single Page Applications (SPAs) require the programmer to write two programs: a Javascript client and a Server, which both must conform to a common API
@@ -228,21 +265,21 @@ Like [Elm](https://elm-lang.org/), it uses an update function to process actions
 Hyperbole depends heavily on the following frameworks
 
 * [Effectful](https://hackage.haskell.org/package/effectful-core)
-* [Web View](https://hackage.haskell.org/package/web-view)
+* [Atomic CSS](https://hackage.haskell.org/package/atomic-css)
 -}
 
 
 {- $hello
 
+
 Hyperbole applications run via [Warp](https://hackage.haskell.org/package/warp) and [WAI](https://hackage.haskell.org/package/wai)
 
 They are divided into top-level 'Page's, which run side effects (such as loading data from a database), then respond with an HTML 'View'. The following application has a single 'Page' that displays a static "Hello World"
 
+#EXAMPLE /intro
+
 @
-{\-# LANGUAGE DeriveAnyClass #-\}
 {\-# LANGUAGE OverloadedStrings #-\}
-{\-# LANGUAGE TypeFamilies #-\}
-{\-# LANGUAGE DataKinds #-\}
 
 module Main where
 
@@ -257,13 +294,15 @@ import Web.Hyperbole
 
 {- $interactive
 
+#EXAMPLE /simple
+
 We can embed one or more 'HyperView's to add type-safe interactivity to live subsections of our 'Page'. To start, first define a data type (a 'ViewId') that uniquely identifies that subsection of the page:
 
 @
 #EMBED Example/Docs/Interactive.hs data Message
 @
 
-Make our 'ViewId' an instance of 'HyperView' by:
+Make our 'ViewId' an instance of 'HyperView':
 
 * Create an 'Action' type with a constructor for every possible way that the user can interact with it
 * Write an 'update' for each 'Action'
@@ -272,15 +311,15 @@ Make our 'ViewId' an instance of 'HyperView' by:
 #EMBED Example/Docs/Interactive.hs instance HyperView Message
 @
 
-If an 'Action' occurs, the contents of our 'HyperView' will be replaced with 'update'.
+If an 'Action' occurs, the contents of our 'HyperView' will be replaced with the result of 'update'.
 
-To embed our new 'HyperView', add the 'ViewId' to the type-level list of 'Page', and then wrap the view in 'hyper'.
+To use our new 'HyperView', add the 'ViewId' to the type-level list of 'Page', and then place it in the page view with 'hyper'.
 
 @
 #EMBED Example/Docs/Interactive.hs page
 @
 
-Now let's add a button to trigger the 'Action'. Note that we must update the 'View'\'s 'context' to match our 'ViewId'. The compiler will tell us if we try to trigger actions that don't belong to our 'HyperView'
+Now let's add a button to trigger the 'Action'. Note that we must now update the 'View'\'s 'context' to match our 'ViewId'. The compiler will tell us if we try to trigger actions that don't belong to our 'HyperView'
 
 @
 #EMBED Example/Docs/Interactive.hs messageView
@@ -292,27 +331,32 @@ If the user clicks the button, the contents of `hyper` will be replaced with the
 
 {- $view-functions-intro
 
-'View's are HTML fragments with embedded CSS
+'View's are HTML fragments with a 'context'
 
 @
 #EMBED Example/Docs/BasicPage.hs helloWorld
 @
 
->>> Web.View.renderText $ el bold "Hello World"
-<style type='text/css'>.bold { font-weight:bold }</style>
-<div class='bold'>Hello World</div>
+>>> renderText helloWorld
+<div>Hello World</div>
 
 We can factor 'View's into reusable functions:
 
+#EXAMPLE /simple
+
 @
 #EMBED Example/Docs/BasicPage.hs messageView
 
 #EMBED Example/Docs/BasicPage.hs page'
 @
 
-We use plain functions to maintain a consistent look and feel rather than stylesheets:
+Using [atomic-css](https://hackage.haskell.org/package/atomic-css) we can use functions to factor styles as well
+
+#EXAMPLE /css
 
 @
+import Web.Atomic.CSS
+
 header = bold
 h1 = header . fontSize 32
 h2 = header . fontSize 24
@@ -321,18 +365,16 @@ page = gap 10
 example = col page $ do
   el h1 "My Page"
 @
-
-See [Web.View](https://hackage.haskell.org/package/web-view) for more details
 -}
 
 
 {- $view-functions
 
-We showed above how we can factor 'View's into functions. It's best-practice to have a __main__ 'View' for each 'HyperView'. These take the form:
+We showed above how we can factor 'View's into functions. It's best-practice to have a main 'View' function for each 'HyperView'. These take the form:
 
 > state -> View viewId ()
 
-There's nothing special about `state` or 'View' functions. They're just functions that take parameters and return a view.
+There's nothing special about `state` or 'View' functions. They're just functions that take input data and return a view.
 
 We can write multiple view functions with our 'HyperView' as the 'context', and factor them however is most convenient:
 
@@ -340,13 +382,13 @@ We can write multiple view functions with our 'HyperView' as the 'context', and
 #EMBED Example/Docs/ViewFunctions.hs messageButton
 @
 
-We can also create 'View' functions that work in any 'context':
+Some 'View' functions can be used in any 'context':
 
 @
 #EMBED Example/Docs/ViewFunctions.hs header
 @
 
-Then we can refactor our main 'View' to use view functions to avoid repeating ourselves
+With those two functions defined, we can refactor our main 'View' to use them and avoid repeating ourselves
 
 @
 #EMBED Example/Docs/ViewFunctions.hs messageView
@@ -367,21 +409,13 @@ We've mentioned most of the Architecture of a hyperbole application, but let's g
 
 {- $practices-multi
 
-We can add as many 'HyperView's to a page as we want. Let's create another 'HyperView' for a simple counter
-
-From [Example.Docs.MultiView](https://github.com/seanhess/hyperbole/blob/0.4/example/Example/Docs/MultiView.hs)
-
-@
-#EMBED Example/Docs/MultiView.hs data Count
+We can add as many 'HyperView's to a page as we want. These can be muliple copies of the same 'HyperView' with unique 'ViewId' values, or completely different 'HyperView's.
+-}
 
 
-#EMBED Example/Docs/MultiView.hs instance HyperView Count
+{- $practices-diff
 
-
-#EMBED Example/Docs/MultiView.hs countView
-@
-
-We can use both 'Message' and 'Count' 'HyperView's in our page, and they will update independently:
+Let's add both 'Count' and 'Message' 'HyperView's to the same page. Each will update independently:
 
 @
 #EMBED Example/Docs/MultiView.hs page
@@ -391,9 +425,9 @@ We can use both 'Message' and 'Count' 'HyperView's in our page, and they will up
 
 {- $practices-same
 
-We can embed multiple copies of the same 'HyperView' as long as the value of 'ViewId' is unique. Let's update `Message` to allow for more than one value:
+We can embed more than one of the same 'HyperView' as long as the value of 'ViewId' is unique. Let's update `Message` to allow for more than one value:
 
-See [Example.Page.Simple](https://docs.hyperbole.live/simple)
+▶️ #EXAMPLE /simple
 
 @
 #EMBED Example/Docs/MultiCopies.hs data Message
@@ -406,33 +440,33 @@ Now we can embed multiple `Message` 'HyperView's into the same page. Each will u
 @
 
 
-This is especially useful if we put identifying information in our 'ViewId', such as a database id. The 'viewId' function gives us access to that info. See the [Contacts Example](https://docs.hyperbole.live/contacts) and the [Lazy Loading Example](https://docs.hyperbole.live/lazyloading)
+This is especially useful if we put identifying information in our 'ViewId', such as a database id. The 'viewId' function can give us access to that info:
 
-From [Example.Page.LazyLoading](https://docs.hyperbole.live/lazyloading)
+#EXAMPLE /data/loadmore
 
 @
-#EMBED Example/Page/LazyLoading.hs data LazyData
+#EMBED Example/Page/DataLists/LoadMore.hs data Languages
 
-#EMBED Example/Page/LazyLoading.hs instance (Debug :> es, GenRandom :> es) => HyperView
+#EMBED Example/Page/DataLists/LoadMore.hs instance HyperView Languages
 @
 -}
 
 
 {- $practices-pages
 
-An app has multiple 'Page's with different 'Route's that each map to a unique url path:
+An app will usually have multiple 'Page's with different 'Route's that each map to a unique url path:
 
 @
 #EMBED Example/Docs/MultiPage.hs data AppRoute
 @
 
-When we define our app, we define a function that maps a 'Route' to a 'Page'
+When we create our app, we can add a router function which maps a 'Route' to a 'Page' with 'routeRequest'. The web page is completely reloaded each time you switch routes. Each 'Page' is completely isolated.
 
 @
 #EMBED Example/Docs/MultiPage.hs main
 @
 
-Each 'Page' is completely independent. The web page is freshly reloaded each time you switch routes. We can add type-safe links to other pages using 'route'
+We can add type-safe links to other pages using 'route'
 
 @
 #EMBED Example/Docs/MultiPage.hs menu
@@ -452,11 +486,11 @@ As shown above, each 'Page' can contain multiple interactive 'HyperView's to add
 
 {- $practices-nested
 
-We can nest smaller, specific 'HyperView's inside of a larger parent. You might need this technique to display a list of items which need to update themselves
+We can nest smaller, more specific 'HyperView's inside of a larger parent. You might need this technique to display a list of items which might also need to update themselves individually
 
-Let's imagine we want to display a list of Todos. The user can mark individual todos complete, and have them update independently. The specific 'HyperView' might look like this:
+Let's imagine we want to display a list of Todos. The user can mark individual todos complete, and have them update independently. The more specific 'HyperView' for each item might look like this:
 
-From [Example.Docs.Nested](https://github.com/seanhess/hyperbole/blob/0.4/example/Example/Docs/Nested.hs)
+#EXAMPLE /examples/todos
 
 @
 #EMBED Example/Docs/Nested.hs data TodoItem
@@ -466,7 +500,7 @@ From [Example.Docs.Nested](https://github.com/seanhess/hyperbole/blob/0.4/exampl
 
 But we also want the entire list to refresh when a user adds a new todo. We need to create a parent 'HyperView' for the whole list.
 
-List all allowed nested views by adding them to 'Require'
+Add any nested 'HyperView's to 'Require' to make sure they are handled. The compiler will let you know if you forget
 
 @
 #EMBED Example/Docs/Nested.hs data AllTodos
@@ -474,12 +508,11 @@ List all allowed nested views by adding them to 'Require'
 #EMBED Example/Docs/Nested.hs instance HyperView AllTodos
 @
 
-Then we can embed the child 'HyperView' into the parent with 'hyper'
+Then we can embed the child 'HyperView' into the parent 'View' just like we do on a 'Page', by using 'hyper'
 
 @
 #EMBED Example/Docs/Nested.hs todosView
 @
-See this technique used in the [TodoMVC Example](https://docs.hyperbole.live/todos)
 -}
 
 
@@ -487,52 +520,54 @@ See this technique used in the [TodoMVC Example](https://docs.hyperbole.live/tod
 
 You may be tempted to use 'HyperView's to create reusable \"Components\". This leads to object-oriented designs that don't compose well. We are using a functional language, so our main unit of reuse should be functions!
 
-We showed earlier that we can write a [View Function](#g:view-functions) with a generic 'context' that we can reuse in any view.  A function like this might help us reuse styles:
+We showed earlier that we can write a [View Function](#g:view-functions) with a generic 'context' that we can reuse in any view.  A function like this might help us reuse styles or layout:
 
 @
 #EMBED Example/Docs/ViewFunctions.hs header
 @
 
-What if we want to reuse functionality too? We can pass an 'Action' into the view function as a parameter:
+But what if we want to reuse interactivity? We can pass an 'Action' into the view function as a parameter:
 
 @
 #EMBED Example/Docs/Component.hs styledButton
 @
 
-We can create more complex view functions by passing state in as a parameter. Here's a button that toggles between a checked and unchecked state:
+We can create more complex view functions by passing state in as a parameter. Here's a button that toggles between a checked and unchecked state for any 'HyperView':
 
 @
-#EMBED Example/View/Inputs.hs toggleCheckBtn
+#EMBED Example/View/Inputs.hs toggleCheckbox
 @
 
-View functions can wrap other Views:
+View functions can be containers which wrap other Views:
 
 @
 #EMBED Example/View/Inputs.hs progressBar
 @
 
 
-Don't leverage 'HyperView's for code reuse. Think about which subsections of a page ought to update independently. Those are 'HyperView's. If you need reusable functionality, use [view functions](#g:viewfunctions) instead.
+Don't use 'HyperView's to keep your code DRY. Think about which subsections of a page ought to update independently. Those are 'HyperView's. If you need reusable interactivity, use [view functions](#g:viewfunctions) whenever possible. See the following example for a more complicated example.
 
-* See [Example.View.DataTable](https://docs.hyperbole.live/datatable) for a more complex example
+#EXAMPLE /data/sortabletable
 -}
 
 
 {- $examples
-https://docs.hyperbole.live is full of live examples demonstrating different features. Each example includes a link to the source code. Some highlights:
+[hyperbole.live](https://hyperbole.live) is full of live examples demonstrating different features. Each example includes a link to the source code. Some highlights:
 
-* [Simple](https://docs.hyperbole.live/simple)
-* [Counter](https://docs.hyperbole.live/counter)
-* [CSS Transitions](https://docs.hyperbole.live/transitions)
-* [Lazy Loading](https://docs.hyperbole.live/lazyloading)
-* [Forms](https://docs.hyperbole.live/formsimple)
-* [Data Table](https://docs.hyperbole.live/datatable)
-* [Sessions](https://docs.hyperbole.live/sessions)
-* [Filter Items](https://docs.hyperbole.live/filter)
-* [Autocomplete](https://docs.hyperbole.live/autocomplete)
-* [Todo MVC](https://docs.hyperbole.live/todos)
+* ▶️ #EXAMPLE /simple
+* ▶️ #EXAMPLE /counter
+* ▶️ #EXAMPLE /concurrency
+* ▶️ #EXAMPLE /state
+* ▶️ #EXAMPLE /requests
+* ▶️ #EXAMPLE /data
+* ▶️ #EXAMPLE /forms
+* ▶️ #EXAMPLE /interactivity
+* ▶️ #EXAMPLE /errors
+* ▶️ #EXAMPLE /oauth2
+* ▶️ #EXAMPLE /javascript
+* ▶️ #EXAMPLE /advanced
 
-The [National Solar Observatory](https://nso.edu) uses Hyperbole for the Level 2 Data creation tool for the [DKIST telescope](https://nso.edu/telescopes/dki-solar-telescope/). It is completely [open source](https://github.com/DKISTDC/level2/). This production application contains complex interfaces, workers, databases, and more.
+The [National Solar Observatory](https://nso.edu) uses Hyperbole to manage Level 2 Data pipelines for the [DKIST telescope](https://nso.edu/telescopes/dki-solar-telescope/). It uses complex user interfaces, workers, databases, and more. [The entire codebase is open source](https://github.com/DKISTDC/level2/).
 -}
 
 
@@ -540,12 +575,12 @@ The [National Solar Observatory](https://nso.edu) uses Hyperbole for the Level 2
 
 'HyperView's are stateless. They 'update' based entirely on the 'Action'. However, we can track simple state by passing it back and forth between the 'Action' and the 'View'
 
-From [Example.Page.Simple](https://docs.hyperbole.live/simple)
+#EXAMPLE /counter
 
 @
-#EMBED Example/Docs/State.hs instance HyperView Message
+#EMBED Example/Page/Counter.hs instance HyperView Counter
 
-#EMBED Example/Docs/State.hs messageView
+#EMBED Example/Page/Counter.hs viewCount
 @
 -}
 
@@ -554,9 +589,9 @@ From [Example.Page.Simple](https://docs.hyperbole.live/simple)
 
 For any real application with more complex state and data persistence, we need side effects.
 
-Hyperbole relies on [Effectful](https://hackage.haskell.org/package/effectful) to compose side effects. We can use effects in a page or an 'update'. The 'Hyperbole' effect gives us access to the 'request' and 'Client' state, including 'session's and the 'query' 'param's. In this example the page keeps the message in the 'query' 'param's
+Hyperbole relies on [Effectful](https://hackage.haskell.org/package/effectful) to compose side effects. We can use effects in a 'Page' or an 'update'. The 'Hyperbole' effect gives us access to the 'request' and client state, including 'session's and the 'query' 'param's. In this example the page keeps the message in the 'query' 'param's
 
-From [Example.Docs.SideEffects](https://github.com/seanhess/hyperbole/blob/0.4/example/Example/Docs/SideEffects.hs)
+#EXAMPLE /state/query
 
 @
 #EMBED Example/Docs/SideEffects.hs page
@@ -567,29 +602,29 @@ From [Example.Docs.SideEffects](https://github.com/seanhess/hyperbole/blob/0.4/e
 
 To use an 'Effect' other than 'Hyperbole', add it as a constraint to the 'Page' and any 'HyperView' instances that need it.
 
-From [Example.Page.Counter](https://docs.hyperbole.live/counter)
+#EXAMPLE /state/effects
 
 @
 {\-# LANGUAGE UndecidableInstances #-\}
 
-#EMBED Example/Page/Counter.hs instance (Reader
+#EMBED Example/Page/State/Effects.hs instance (Reader
 @
 
 Then run the effect in your application
 
 @
-#EMBED Example/Page/Counter.hs app
+#EMBED Example/Page/State/Effects.hs app
 @
 
-* Read more about [Effectful](https://hackage.haskell.org/package/effectful)
+See [Effectful](https://hackage.haskell.org/package/effectful) to read more about Effects
 -}
 
 
 {- $state-databases
 
-A database is no different from any other 'Effect'. We recommend you create a custom effect to describe high-level data operations.
+A database is no different from any other 'Effect'. It is recommended to create a custom effect to describe high-level data operations.
 
-From [Example.Effects.Todos](https://github.com/seanhess/hyperbole/blob/0.4/example/Example/Effects/Todos.hs)
+#EXAMPLE /examples/todos
 
 @
 #EMBED Example/Effects/Todos.hs data Todos
@@ -597,27 +632,41 @@ From [Example.Effects.Todos](https://github.com/seanhess/hyperbole/blob/0.4/exam
 #EMBED Example/Effects/Todos.hs loadAll
 @
 
-Once you've created an 'Effect', you add it to any 'HyperView' or 'Page' as a constraint.
-
-From [Example.Page.Todo](https://docs.hyperbole.live/todos):
+Just like any effect, to use our custom 'Effect', we add it to any 'HyperView' or 'Page' as a constraint.
 
 @
 {\-# LANGUAGE UndecidableInstances #-\}
 
-#EMBED Example/Page/Todo.hs simplePage
+#EMBED Example/Page/Todos/Todo.hs simplePage
 @
 
-We run a custom effect in our Application just like any other. Here we implementing our custom effect using 'Hyperbole' 'sessions', but you could write a different runner that connects to a database instead.
+We run a custom effect in our Application just like any other. The TodoMVC example implements the Todos 'Effect' using 'Hyperbole' 'sessions', but you could write a different runner that connects to a database instead.
 
 @
-#EMBED Example/Page/Todo.hs main
+#EMBED Example/Page/Todos/Todo.hs main
 @
 
-See [example/Main](https://github.com/seanhess/hyperbole/blob/0.4/example/Main.hs) for a full example application with multiple effects
-
 Implementing a database runner for a custom 'Effect' is beyond the scope of this documentation, but see the following:
 
 * [Effectful.Dynamic.Dispatch](https://hackage.haskell.org/package/effectful-core/docs/Effectful-Dispatch-Dynamic.html) - Introduction to Effects
 * [NSO.Data.Datasets](https://github.com/DKISTDC/level2/blob/main/src/NSO/Data/Datasets.hs) - Production Data Effect with a database runner
 * [Effectful.Rel8](https://github.com/DKISTDC/level2/blob/main/types/src/Effectful/Rel8.hs) - Effect for the [Rel8](https://hackage.haskell.org/package/rel8) Postgres Library
 -}
+
+
+{- $query
+#EXAMPLE /state/query
+-}
+
+
+{- $sessions
+#EXAMPLE /state/sessions
+-}
+
+
+{- $forms
+
+Painless forms with type-checked field names, and support for validation.
+
+#EXAMPLE /forms
+-}
