@@ -1,11 +1,13 @@
 module Web.Hyperbole.Effect.Request where
 
+import Data.String.Conversions (cs)
 import Effectful
 import Effectful.Dispatch.Dynamic
 import Web.FormUrlEncoded (Form, urlDecodeForm)
+import Web.Hyperbole.Data.URI (Path (..))
 import Web.Hyperbole.Effect.Hyperbole
-import Web.Hyperbole.Effect.Server
-import Web.View
+import Web.Hyperbole.Types.Request
+import Web.Hyperbole.Types.Response
 
 
 -- | Return all information about the 'Request'
@@ -18,7 +20,7 @@ request = send GetRequest
 >>> reqPath
 ["users", "100"]
 -}
-reqPath :: (Hyperbole :> es) => Eff es [Segment]
+reqPath :: (Hyperbole :> es) => Eff es Path
 reqPath = (.path) <$> request
 
 
@@ -30,4 +32,4 @@ formBody :: (Hyperbole :> es) => Eff es Form
 formBody = do
   b <- (.body) <$> request
   let ef = urlDecodeForm b
-  either (send . RespondEarly . Err . ErrParse) pure ef
+  either (send . RespondNow . Err . ErrParse . cs) pure ef
